intelmq.bots.collectors.xmpp package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.collectors.xmpp package

## Submodules

## intelmq.bots.collectors.xmpp.collector module

XMPP Collector Bot Connects to a XMPP Server and a Room and reads data from the room. If no room is provided, which is equivalent to an empty string, it only collects events which were sent to the xmpp user directly.

TLS is used by default.

Tested with Python >= 3.4 Tested with sleekxmpp >= 1.0.0-beta5

Copyright (C) 2016 by Bundesamt für Sicherheit in der Informationstechnik Software engineering by Intevation GmbH

Parameters: ca_certs: string to a CA-bundle file or false/empty string for no checks strip_message: boolean xmpp_user: string xmpp_server: string xmpp_password: boolean xmpp_room: string xmpp_room_password: string xmpp_room_nick: string pass_full_xml: boolean strip_message: boolean xmpp_userlist: array xmpp_whitelist_mode: boolean

`intelmq.bots.collectors.xmpp.collector.` `BOT`

  alias of `intelmq.bots.collectors.xmpp.collector.XMPPCollectorBot`

class `intelmq.bots.collectors.xmpp.collector.` `XMPPCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  `collector_empty_process` = True
  `init`()
  `log_message`(msg)
  `process`()
  `shutdown`()
  `xmpp` = None

## Module contents